==> opencity-0.0.5.1stable.tar.bz2: opencity-0.0.5stable/src/structure/pathstructure.h <==
/***************************************************************************
						pathstructure.h  -  description
							-------------------
	begin                : june 17th, 2003
	copyright            : (C) 2003-2007 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net
	
	$Id: pathstructure.h 174 2007-02-22 20:09:35Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/

#ifndef _OPENCITY_PATHSTRUCTURE_H_
#define _OPENCITY_PATHSTRUCTURE_H_ 1

#include "structure.h"

enum OPENCITY_DIRECTION;


/** This is a specialization of Structure. It regroups all structures
like Road, Rails, WaterPipe, GasPipe, HighWay, ElecLine etc...
*/
class PathStructure : public Structure  {
public:
	/** Should not be used */
	PathStructure();
	PathStructure( const OPENCITY_STRUCTURE_CODE & enumStructCode );
	virtual ~PathStructure();   // virtual since Structure's one is


//========================================================================
/** Overload the Structure::SaveTo
	\param rfs A reference to a file stream which is ready for writing
	\see Structure::SaveTo()
*/
	void
	SaveTo( std::fstream& rfs );


//========================================================================
/** Overload the Structure::LoadFrom
	\param rfs A reference to a file stream which is ready for reading
	\see Structure::LoadFrom
*/
	void
	LoadFrom( std::fstream& rfs );


	void
	AddNeighbour(
		const PathStructure & rcNeighbour,
		const OPENCITY_DIRECTION & enumDir );


	void
	RemoveNeighbour(
		const PathStructure & rcNeighbour,
		const OPENCITY_DIRECTION & enumDir );


	const OC_UBYTE &
	GetTraffic() const;

	void
	SetTraffic(
		const OC_UBYTE & rubTraffic );

	const uint &
	GetLength() const;

	void
	SetLength(
		const uint & rcuiValue );


private:
	OC_UBYTE ubNumberNeighbour;
	OC_UBYTE ubTraffic;

	uint uiLength;		// for pathfinding purpose
};

#endif

==> opencity-0.0.6.2stable.tar.bz2: opencity-0.0.6.2stable/src/structure/pathstructure.h <==
/***************************************************************************
						pathstructure.h  -  description
							-------------------
	begin                : june 17th, 2003
	copyright            : (C) 2003-2007 by Duong Khang NGUYEN
	email                : neoneurone @ gmail com
	
	$Id: pathstructure.h 375 2008-10-28 14:47:15Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/

#ifndef _OPENCITY_PATHSTRUCTURE_H_
#define _OPENCITY_PATHSTRUCTURE_H_ 1

#include "structure.h"

enum OPENCITY_DIRECTION;


/** This is a specialization of Structure. It regroups all structures
like Road, Rails, WaterPipe, GasPipe, HighWay, ElecLine etc...
*/
class PathStructure : public Structure  {
public:
	/** Should not be used */
	PathStructure();
	PathStructure( const OPENCITY_STRUCTURE_CODE & enumStructCode );
	virtual ~PathStructure();   // virtual since Structure's one is


//========================================================================
/** Overload the Structure::SaveTo
	\param rfs A reference to a file stream which is ready for writing
	\see Structure::SaveTo()
*/
	void
	SaveTo( std::fstream& rfs );


//========================================================================
/** Overload the Structure::LoadFrom
	\param rfs A reference to a file stream which is ready for reading
	\see Structure::LoadFrom
*/
	void
	LoadFrom( std::fstream& rfs );


	void
	AddNeighbour(
		const PathStructure & rcNeighbour,
		const OPENCITY_DIRECTION & enumDir );


	void
	RemoveNeighbour(
		const PathStructure & rcNeighbour,
		const OPENCITY_DIRECTION & enumDir );


	const OC_UBYTE &
	GetTraffic() const;

	void
	SetTraffic(
		const OC_UBYTE & rubTraffic );

	const uint &
	GetLength() const;

	void
	SetLength(
		const uint & rcuiValue );


private:
	OC_UBYTE ubNumberNeighbour;
	OC_UBYTE ubTraffic;

	uint uiLength;		// for pathfinding purpose
};

#endif
